# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ....dyn.deployment.ui.license_dialog import LicenseDialog as LicenseDialog
from ....dyn.deployment.ui.package_manager_dialog import PackageManagerDialog as PackageManagerDialog
from ....dyn.deployment.ui.update_required_dialog import UpdateRequiredDialog as UpdateRequiredDialog
